@@ -1,10 +1,10 @@
 """
 parser package (imdb package).
 
-This package provides various parser to access IMDb data (e.g.: a
+This package provides various parsers to access IMDb data (e.g.: a
 parser for the web/http interface, a parser for the local files,
-a parser for the e-mail interface, etc.).
-So far, the http and local parsers are implemented.
+a parser for the SQL database interface, etc.).
+So far, the http/httpThin, local, mobile and sql parsers are implemented.
 
 Copyright 2004, 2005 Davide Alberani <da@erlug.linux.it>
 
@@ -23,6 +23,6 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """
 
-__all__ = ['http', 'local', 'mobile']
+__all__ = ['http', 'local', 'mobile', 'sql']
 
 
